## R -d "valgrind -tool=memcheck"
## source("valgrind.R")


if (FALSE)
  {

    if (file.exists("source.R")) source("source.R")
    example(BITOEK)
    example(mpp.characteristics)
    example(rfm.test)
    example(simulateMPP)
    example(splitmodel)
    example(srd)
    
}
